@@ -34,18 +34,14 @@ Group by StressVowel,buckeye_speaker.Number""")
     return dist
 
 
-def loadFile(path,cols=[]):
-    cols = set(cols)
-    f = open(path,'r').read().splitlines()
-    head = f[0].split("\t")
-    lines = []
-    for i in xrange(1,len(f)):
-        line = f[i].split("\t")
-        newline = {}
-        for j in xrange(len(head)):
-            if head[j] in cols:
-                newline[head[j]] = line[j]
-        lines.append(newline)
+def loadFile(path,cols=None):
+    with open(path,'r') as f:
+        head = pop(f,0).strip().split("\t")
+        lines = []
+        for l in f:
+            line = l.strip().split("\t")
+            newline = { h: line[i] for i,h in enumerate(head) if cols is None or h in cols}
+            lines.append(newline)
     return lines
 
 def get_outliers(filename):
